BluedotPointSdk class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
backgroundLocationAccessForWhileUsing(
bool value) → void - Enable or disable background location updates (iOS only)
-
geoTriggeringBuilder(
) → GeoTriggeringBuilder - GeoTriggeringBuilder is use to build GeoTriggeringService object.
-
getCustomEventMetaData(
) → Future -
Returns a collection of
CustomEventMetaDataobjects, corresponding to the HashMap of Key Value Pairs <String, String> -
getInstallRef(
) → Future< String> - Returns the installation reference of this PointSDK enabled App.
-
getSDKVersion(
) → Future< String> - Returns the version of the Point SDK as a String.
-
getZonesAndFences(
) → Future -
Returns a collection of
BDZoneInfoobjects, corresponding to the Zones created for this project in the Canvas portal. -
initialize(
String projectId) → Future< void> -
Initialize PointSDK with
projectId. You can find yourprojectIdon Bluedot Canvas portal. -
isGeoTriggeringRunning(
) → Future< bool> - Method to determine if GeoTriggering is running.
-
isInitialized(
) → Future< bool> - Method to determine if the PointSDK is initialized.
-
isTempoRunning(
) → Future< bool> - Method to determine if Tempo is running
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → Future< void> - Reset Bluedot PointSDK (only if you wish to switch to a different projectId)
-
setCustomEventMetaData(
Map< String, String> metadata) → Future<void> - Sets custom metadata for Notification events.
-
setNotificationIcon(
String icon) → Future< void> -
By default, PointSDK uses
ic_stat_nameicon in res/drawable resources for GeoTriggering and Tempo services foreground notification icons. -
setZoneDisableByApplication(
String zoneId, bool disable) → Future< void> -
Disable or re-enable a specific zone by its
zoneId. -
stopGeoTriggering(
) → Future< void> - Stops GeoTriggering feature of the Bluedot PointSDK
-
stopTempoTracking(
) → Future< void> - Stops Tempo Tracking
-
tempoBuilder(
) → TempoBuilder - TempoBuilder is use to build TempoService object
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → BluedotPointSdk
-
The singleton instance of Bluedot Point SDK
final
Constants
- bluedotService → const String
- geoTriggering → const String
- tempo → const String