setCustomEventMetaData method

Future<void> setCustomEventMetaData(
  1. Map<String, String> metadata
)

Sets custom metadata for Notification events.

Only up to 20 custom meta data fields are allowed. Will throw an exception if the number of custom fields exceeds the limit. The custom metadata set through this API will be available on the backend in check-in activity log and via webhooks.

Implementation

Future<void> setCustomEventMetaData(Map<String, String> metadata) {
  return BluedotPointSdkPlatform.instance.setCustomEventMetaData(metadata);
}