stopGeoTriggering method

Future<void> stopGeoTriggering()

Stops GeoTriggering feature of the Bluedot PointSDK

Stopping Geo-triggering feature has the intended effect of stopping location services on the device, thereby conserving battery on your user’s device unless another feature such as Tempo, is active. If Geo-Triggering feature is stopped successfully, error will be returned as nil. Otherwise, an error will be provided.

Implementation

Future<void> stopGeoTriggering() {
  return BluedotPointSdkPlatform.instance.stopGeoTriggering();
}