GeoTriggeringBuilder class

Constructors

GeoTriggeringBuilder()

Properties

androidNotificationContent ↔ String?
getter/setter pair
androidNotificationId ↔ int
getter/setter pair
androidNotificationTitle ↔ String?
getter/setter pair
channelId ↔ String?
getter/setter pair
channelName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iosAppRestartNotificationButtonText ↔ String?
getter/setter pair
iosAppRestartNotificationTitle ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

androidNotification(String? channelId, String? channelName, String? androidNotificationTitle, String? androidNotificationContent, int androidNotificationId) → GeoTriggeringBuilder
Set parameters for foreground service notification. Only required for apps targeting Android O and above.
iosNotification(String? iosAppRestartNotificationTitle, String? iosAppRestartNotificationButtonText) → GeoTriggeringBuilder
Set parameters for iOS Restart notification.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → Future<void>
Start GeoTriggering features of the Bluedot Point SDK
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited